const loader = require("./index");

module.exports = loader.default;
module.exports.pitch = loader.pitch;
